<?php
// Include database configuration
require_once 'config.php';

// Set the content type to JSON
header('Content-Type: application/json');

// Check if 'id' parameter is provided
if (isset($_GET['id']) && !empty($_GET['id'])) {
    // Retrieve the policy ID from the request
    $policyId = intval($_GET['id']);

    // Prepare the SQL query
    $query = "SELECT id, name, description, price, status FROM insurance_schemes WHERE id = ?";
    
    // Initialize database connection
    $stmt = $conn->prepare($query);

    if ($stmt) {
        // Bind parameters
        $stmt->bind_param("i", $policyId);

        // Execute the query
        $stmt->execute();

        // Fetch the result
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            // Fetch the policy details
            $policy = $result->fetch_assoc();

            // Return the policy details as JSON
            echo json_encode($policy);
        } else {
            // Return an error if no policy is found
            echo json_encode([
                'error' => 'No policy found for the given ID.'
            ]);
        }

        // Close the statement
        $stmt->close();
    } else {
        // Return an error if the query preparation fails
        echo json_encode([
            'error' => 'Failed to prepare the SQL statement.'
        ]);
    }
} else {
    // Return an error if 'id' parameter is not provided
    echo json_encode([
        'error' => 'Invalid or missing ID parameter.'
    ]);
}

// Close the database connection
$conn->close();
?>
