<?php
session_start();
include('config.php'); // Ensure this file connects to your database

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if CheckoutRequestID exists in the session
    if (isset($_SESSION["CheckoutRequestID"])) {
        $checkoutRequestID = $_SESSION["CheckoutRequestID"];

        // Prepare the SQL query to fetch the payment status
        $stmt = $conn->prepare("SELECT * FROM `orders` WHERE `CheckoutRequestID` = ?");
        $stmt->bind_param("s", $checkoutRequestID);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $order = $result->fetch_assoc();
            $status = $order['Status']; // Assuming the column name is `Status`

            // Display messages based on the status
            if ($status === 'SUCCESS') {
                $message = "Payment has been successfully completed.";
            } elseif ($status === 'CANCELLED') {
                $message = "Payment has failed. Please try again.";
            } else {
                $message = "Payment is still pending. Please check again later.";
            }
        } else {
            $message = "No order found with the given Checkout Request ID.";
        }

        $stmt->close();
    } else {
        $message = "No Checkout Request ID found in the session.";
    }
}
?>
<!DOCTYPE html>
<html>
<head>
    <style>
        @import url(https://fonts.googleapis.com/css?family=Lato:400,100,300,700,900);
        @import url(https://fonts.googleapis.com/css?family=Source+Code+Pro:400,200,300,500,600,700,900);
        .container {
            display: flex;
            align-items: center;
            justify-content: center;
            height: 100vh;
            flex-direction: column;
        }
        * {
            box-sizing: border-box;
        }
        html {
            background-color: #171A3D;
            font-family: 'Lato', sans-serif;
        }
        .message {
            text-align: center;
            color: #18C2C0;
            margin-bottom: 20px;
        }
        .price h1 {
            font-weight: 300;
            color: #18C2C0;
            letter-spacing: 2px; 
            text-align: center;
        }
        .card {
            margin-top: 30px;
            margin-bottom: 30px;
            width: 520px;
        }
        .card .row {
            width: 100%;
            padding: 1rem 0;
            border-bottom: 1.2px solid #292C58;
        }
        .card .row.number {
            background-color: #242852;
        }
        .cardholder .info, .number .info {
            position: relative;
            margin: 0 40px;
        }
        .cardholder .info label, .number .info label {
            display: inline-block;
            letter-spacing: 0.5px;
            color: #8F92C3;
            width: 40%;
        }
        .cardholder .info input, .number .info input {
            display: inline-block;
            width: 55%;
            background-color: transparent;
            font-family: 'Source Code Pro';
            border: none;
            outline: none;
            margin-left: 1%;
            color: white;
        }
        .button button {
            font-size: 1.2rem;
            font-weight: 400;
            letter-spacing: 1px;
            width: 520px;
            background-color: #18C2C0;
            border: none;
            color: #fff;
            padding: 18px;
            border-radius: 5px;
            outline: none;
            cursor: pointer;
            transition: background-color 0.2s cubic-bezier(0.4, 0, 0.2, 1);
        }
        .button button:hover {
            background-color: #15aeac;
        }
        .button button:active {
            background-color: #139b99;
        }
    </style>
</head>
<body>
<div class="container">
    <?php if (!empty($message)): ?>
        <div class="message">
            <h2><?php echo htmlspecialchars($message); ?></h2>
        </div>
    <?php endif; ?>
    <form action="" method="POST">
        <div class="price">
            <h1>Awesome, that's KES 100</h1>
        </div>
        <div class="card__container">
            <div class="card">
                <div class="row">
                    <img src="mpesa.png" style="width:30%;margin: 0 35%;">
                </div>
                <div class="row number">
                    <div class="info">
                        <p style="color:#8F92C3;line-height:1.7;">
                            3. After receiving the payment confirmation message, press "Confirm Payment" to finish making your order.
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <div class="button">
            <button type="submit">Confirm Payment</button>
        </div>
    </form>
    <p style="color:#8F92C3;line-height:1.7;margin-top:5rem;">
        Copyright 2022 | All Rights Reserved | Made by MediaForce
    </p>
</div>
</body>
</html>
