<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: *'); // Allow all origins
header('Access-Control-Allow-Headers: Content-Type'); // Allow specific headers

// Include the database configuration file
require_once 'config.php';

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Get the raw POST data
    $postData = file_get_contents('php://input');

    // Decode the JSON data
    $data = json_decode($postData, true);

    // Check if email and password are provided
    if (isset($data['email']) && isset($data['password'])) {
        $email = $data['email'];
        $password = $data['password'];

        // Prepare and execute a query to fetch user details
        $stmt = $conn->prepare("SELECT id, email, password FROM users WHERE email = ?");
        $stmt->bind_param('s', $email);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            // Fetch the user data
            $user = $result->fetch_assoc();

            // Verify the password
            if (password_verify($password, $user['password'])) {
                // Password is correct, return success response
                echo json_encode([
                    'success' => true,
                    'message' => 'Login successful.',
                    'user_id' => $user['id'],
                    'email' => $user['email'],
                ]);
            } else {
                // Incorrect password
                echo json_encode([
                    'success' => false,
                    'message' => 'Invalid email or password.',
                ]);
            }
        } else {
            // User not found
            echo json_encode([
                'success' => false,
                'message' => 'Invalid email or password.',
            ]);
        }

        $stmt->close();
    } else {
        // Missing required fields
        echo json_encode([
            'success' => false,
            'message' => 'Email and password are required.',
        ]);
    }
} else {
    // Invalid request method
    echo json_encode([
        'success' => false,
        'message' => 'Invalid request method.',
    ]);
}

// Close the database connection
$conn->close();
